// SPDX-FileCopyrightText: 2021 - 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#include <QtCore/qglobal.h>

#define WIDGETS_NAMESPACE Widgets

#define WIDGETS_BEGIN_NAMESPACE namespace WIDGETS_NAMESPACE {
#define WIDGETS_END_NAMESPACE }
#define WIDGETS_USE_NAMESPACE using namespace WIDGETS_NAMESPACE;
